aboutsummaryrefslogtreecommitdiffstats
path: root/plugins/wimax/msg_reg_req.c
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/wimax/msg_reg_req.c')
-rw-r--r--plugins/wimax/msg_reg_req.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/plugins/wimax/msg_reg_req.c b/plugins/wimax/msg_reg_req.c
index 0f5dfd9f13..06f7d08d73 100644
--- a/plugins/wimax/msg_reg_req.c
+++ b/plugins/wimax/msg_reg_req.c
@@ -36,7 +36,7 @@
#include "moduleinfo.h"
-#include <gmodule.h>
+#include <glib.h>
#include <epan/packet.h>
#include <epan/prefs.h>
#include "crc.h"
@@ -924,8 +924,8 @@ void dissect_extended_tlv(proto_tree *reg_req_tree, gint tlv_type, tvbuff_t *tvb
guint length;
guint nblocks;
- /* Get the tvb length */
- tvb_len = tvb_length(tvb);
+ /* Get the tvb reported length */
+ tvb_len = tvb_reported_length(tvb);
/* get the TLV information */
init_tlv_info(&tlv_info, tvb, offset);
@@ -1242,8 +1242,8 @@ void dissect_mac_mgmt_msg_reg_req_decoder(tvbuff_t *tvb, packet_info *pinfo, pro
if (tree)
{ /* we are being asked for details */
- /* Get the tvb length */
- tvb_len = tvb_length(tvb);
+ /* Get the tvb reported length */
+ tvb_len = tvb_reported_length(tvb);
/* display MAC payload type REG-REQ */
reg_req_item = proto_tree_add_protocol_format(tree, proto_mac_mgmt_msg_reg_req_decoder, tvb, offset, tvb_len, "MAC Management Message, REG-REQ (6)");
/* add MAC REG-REQ subtree */